.. currentmodule:: abjad.tools.pitchtools

list_numbered_inversion_equivalent_interval_classes_pairwise
============================================================

.. autofunction:: list_numbered_inversion_equivalent_interval_classes_pairwise
